==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/guardduty/kotlin/inputs/FilterFindingCriteriaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.guardduty.kotlin.inputs

import com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property criterions
 */
public data class FilterFindingCriteriaArgs(
    public val criterions: Output<List<FilterFindingCriteriaCriterionArgs>>,
) : ConvertibleToJava<com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs> {
    override fun toJava(): com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs =
        com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs.builder()
            .criterions(
                criterions.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FilterFindingCriteriaArgs].
 */
@PulumiTagMarker
public class FilterFindingCriteriaArgsBuilder internal constructor() {
    private var criterions: Output<List<FilterFindingCriteriaCriterionArgs>>? = null

    /**
     * @param value
     */
    @JvmName("nungkwivvlofrnss")
    public suspend fun criterions(`value`: Output<List<FilterFindingCriteriaCriterionArgs>>) {
        this.criterions = value
    }

    @JvmName("wjsmykouavnajydj")
    public suspend fun criterions(vararg values: Output<FilterFindingCriteriaCriterionArgs>) {
        this.criterions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ivhivntveooenrbl")
    public suspend fun criterions(values: List<Output<FilterFindingCriteriaCriterionArgs>>) {
        this.criterions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mpycxoydjhpvpgin")
    public suspend fun criterions(`value`: List<FilterFindingCriteriaCriterionArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.criterions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("oagdnbtwborptdkv")
    public suspend
    fun criterions(argument: List<suspend FilterFindingCriteriaCriterionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FilterFindingCriteriaCriterionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.criterions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("xdmxsbomqnfcchgw")
    public suspend fun criterions(
        vararg
        argument: suspend FilterFindingCriteriaCriterionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            FilterFindingCriteriaCriterionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.criterions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("anihlxcnyxbtivos")
    public suspend
    fun criterions(argument: suspend FilterFindingCriteriaCriterionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            FilterFindingCriteriaCriterionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.criterions = mapped
    }

    /**
     * @param values
     */
    @JvmName("qygusvftjidqoshv")
    public suspend fun criterions(vararg values: FilterFindingCriteriaCriterionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.criterions = mapped
    }

    internal fun build(): FilterFindingCriteriaArgs = FilterFindingCriteriaArgs(
        criterions = criterions ?: throw PulumiNullFieldException("criterions"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/guardduty/kotlin/inputs/FilterFindingCriteriaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.guardduty.kotlin.inputs

import com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property criterions
 */
public data class FilterFindingCriteriaArgs(
    public val criterions: Output<List<FilterFindingCriteriaCriterionArgs>>,
) : ConvertibleToJava<com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs> {
    override fun toJava(): com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs =
        com.pulumi.aws.guardduty.inputs.FilterFindingCriteriaArgs.builder()
            .criterions(
                criterions.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FilterFindingCriteriaArgs].
 */
@PulumiTagMarker
public class FilterFindingCriteriaArgsBuilder internal constructor() {
    private var criterions: Output<List<FilterFindingCriteriaCriterionArgs>>? = null

    /**
     * @param value
     */
    @JvmName("mpahdtatoiuxkaad")
    public suspend fun criterions(`value`: Output<List<FilterFindingCriteriaCriterionArgs>>) {
        this.criterions = value
    }

    @JvmName("wjashgxomwxdrsnw")
    public suspend fun criterions(vararg values: Output<FilterFindingCriteriaCriterionArgs>) {
        this.criterions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("gskqbhepwcxwgrgw")
    public suspend fun criterions(values: List<Output<FilterFindingCriteriaCriterionArgs>>) {
        this.criterions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ufiyqtaupeqbebeb")
    public suspend fun criterions(`value`: List<FilterFindingCriteriaCriterionArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.criterions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wcvrrtcdjxlvjgwk")
    public suspend fun criterions(argument: List<suspend FilterFindingCriteriaCriterionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FilterFindingCriteriaCriterionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.criterions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lkxbutysaasmbuey")
    public suspend fun criterions(vararg argument: suspend FilterFindingCriteriaCriterionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            FilterFindingCriteriaCriterionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.criterions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ijeyncvrpbdgqqjb")
    public suspend fun criterions(argument: suspend FilterFindingCriteriaCriterionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            FilterFindingCriteriaCriterionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.criterions = mapped
    }

    /**
     * @param values
     */
    @JvmName("dlkeusaedhgepdnl")
    public suspend fun criterions(vararg values: FilterFindingCriteriaCriterionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.criterions = mapped
    }

    internal fun build(): FilterFindingCriteriaArgs = FilterFindingCriteriaArgs(
        criterions = criterions ?: throw PulumiNullFieldException("criterions"),
    )
}
